import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  scaleOrdinal,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis,
  nest,
  schemeCategory10,
  descending
} from 'd3';

 const render = data => {
  const xValue = d => d.year;
  const xAxisLabel = '';
  const yValue = d => d['8.0+'];
  const y2Value = d => d['7_7.9'];
  const y3Value = d => d['6_6.9'];
  const y4Value = d => d['5_5.9'];
  const svg = select('svg');
  const width = +svg.attr('width');
  const height = +svg.attr('height');

  const yAxisLabel = '';
  const margin = { top: 60, right: 50, bottom: 80, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
 
 
   const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([20, innerWidth - 40])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain([min(data, d => yValue(d)),max(data, d => y3Value(d))])
  	.range([innerHeight, 0])
  	.nice();
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(0)
  	.tickValues(xScale.domain())
  	.tickPadding(20);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
    .tickPadding(15);
   const yAxisGroup = g.append('g').call(yAxis);
  
  yAxisGroup
  	.selectAll('.domain')
  		.remove();
  
  yAxisGroup.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -90)
  	.attr('x', -innerHeight / 2)
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
    
    
  const xAxisGroup = g.append('g').call(xAxis)
  	.attr('transform', `translate(10,${innerHeight})`);
  
  xAxisGroup.selectAll('.domain').remove();
  
  xAxisGroup.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', margin.bottom - 10)
  	.attr('x', innerWidth / 2)
  	.text(xAxisLabel);
  const line3Generator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(y3Value(d)))
  	.curve(curveCatmullRom.alpha(0.4));
  
  const line4Generator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(y4Value(d)))
  	.curve(curveCatmullRom.alpha(0.4));

  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveCatmullRom.alpha(0.4));
   g.append('path')
  	.attr('class', 'line-path-Africa')
  	.attr('d', lineGenerator(data));
  
  }
  
  d3.csv("q3.csv")
    .then(data => {
    data.forEach(d => {
      d['8.0+'] = +d['8.0+'];
      d.year = new Date(d.year);
    });
    render(data)
    console.log(data)
  });